/***************************************************/
/*! \class AllPass
 \brief
 
 The AudioDrome AllPass class, 
 implements a IIR-filter (infinite impule response filter).
 
 * ===================================================
 * 		    ____________ -g __________
 * 		   |                          |
 *  input --- + --[..... d.....] ----- + --- Processing()
 * 	         |_________ g ________|
 * ===================================================
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef ALLPASS_H_
#define ALLPASS_H_

#include "Comb.h"



namespace Aud
{
	
	class AllPass : public Comb
		{
		public:
			//! Public constructor
			/*
			 * N.B. The interpolation, cause a low-pass frequency response
			 */
			AllPass(const AudFloat &delayMax=1, const INTERPOLATION& type=DISABLED);
			
			//! Public destructor
			virtual ~AllPass();
			
		protected:
			//! Processing the audio sample
			/*!
			 * AllPass network (a.k.a. allpass filter) as documented by F. Richard Moore.
			 * ===================================================
			 * 		       ____________ -g __________
			 * 		      |                          |
			 *  Input() --- + --[..... d.....] ----- + --- Output()
			 * 	            |_________ g ________|
			 * ===================================================
			 */
			virtual void Processing();
			
		private:
			AudFloat _sampleHold;
			AudFloat _out;
		};
}
#endif /*ALLPASS_H_*/
