/***************************************************/
/*! \class BP_Butterworth Filter
 \brief
 
 The AudioDrome BP_Butterworth class, implements a 
 band-pass Butterworth filter. 
 Coded by Paris Smaragdis 1994
 
 Csound's code butter.c
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef BP_BUTTERWORTH_H_
#define BP_BUTTERWORTH_H_

#include "LP_Butterworth.h"

//  begin namespace
namespace Aud
{
	class BP_Butterworth : public LP_Butterworth
		{
		public:
			//! Public Constructor
			BP_Butterworth(const AudFloat &centerFreq=50000,
						   const AudFloat &bandWidth=500);
			
			//! Public Destructor
			virtual ~BP_Butterworth();
			
			//! Sets the center frequency for the filter in Hz
			virtual void setCenterFrequency(const AudFloat &centerFreq);
			
			//! Sets the bandwidth of the filter in Hz
			virtual void setBandWidth(const AudFloat &bandWidth);
			
		protected:
			AudFloat _cf;
			AudFloat _bw;			
			
			virtual void srUpdate()
			{ 
				LP_Butterworth::srUpdate();
				this->setCenterFrequency(_cf);
			}
			
		private:
			void setCutOff(const AudFloat &cutOff);	
		};
} //	end of namespace Aud

#endif /*BP_BUTTERWORTH_H_*/
///EOF
