/***************************************************/
/*! \class BandReject Filter (notch)
 \brief
 
 The AudioDrome BandReject class, implements a second-order band-reject (notch) filter.
 
 Csound's code, based on Robin Whittle's
 ugrw2.c and ugrw2.h of 9 September 1995
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef BANDREJECT_H
#define BANDREJECT_H

#include "BandPass.h"

//  begin namespace
namespace Aud
{
	class BandReject : public BandPass
		{
		public:
			//! Public constructor
			BandReject(const AudFloat &centerFreq=15000,
					   const AudFloat &bandWidth=5000, const SCALING &scale=CENTRE);
			
			//! Public destructor
			virtual ~BandReject();
			
		protected: 
			//! Processing the audio sample
			virtual void Processing();
			
		private:
			AudFloat _D;
			virtual void scaling(const SCALING &scale);
		};
} //	end of namespace Aud
#endif
///EOF

