/***************************************************/
/*! \class Comb
 \brief
 
 The AudioDrome Comb class, 
 implements a IIR-filter (infinite impulse response filter).
 
 * ===================================================
 *  input -- + -[..... d.....] --------- out delay 2
 * 	        |________ g ________|
 * ===================================================
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef COMB_H_
#define COMB_H_

#include "DelayTaps.h"

namespace Aud
{
	class Comb : public DelayTaps
		{
		public:
			//! Public constructor
			/*
			 * N.B.
			 * If interpolation is enabled, cause 
			 * a low-pass frequency response.
			 */
			Comb(const AudFloat &delayMax=1, const INTERPOLATION& type=DISABLED);
			
			//! Public destructor
			virtual ~Comb();
			
			//! Reverberation time in seconds
			/*
			 * This function implicitly calculates the gain of the feedback.
			 */
			void setT60(const AudFloat& t60);
			
			//! Sets the gain of feedback (0 <= gain <= 1)
			/*
			 * This function implicitly calculates the t60 time.
			 */
			void setGain(const AudFloat& gain);
			
			//! Algorithms select type 
			/*!
			 * FEEDBACK (IIR) o FEEDFORWARD (FIR)
			 */
			//	void setCombType(const FILTERTYPE& filterType=FEEDBACK);//Not implemented!!!!!!
			
		protected:
			//! Processing the audio sample
			/*!
			 * ===================================================
			 *  Input() -- + -[..... d.....] --------- Output()
			 * 	           |________ g ________|
			 * ===================================================
			 */
			virtual void Processing();
			
			AudFloat _t60;
			AudFloat _gain;
		};
} //	end of namespace Aud
#endif /*COMB_H_*/
///EOF
