/***************************************************/
/*! \class Curve
 \brief
 
 The AudioDrome Curve class, constructs only a segment
 between two points expressed like "start, end".
 The segment duration is expressed in seconds and 
 the segment can be assume a specific curving through setCurve()
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef CURVE_H
#define CURVE_H

#include "Line.h"

//  begin namespace
namespace Aud
{
	class Curve : virtual public Line
	{
	public:
		//! Public constructor
		Curve();
		
		//! Public destructor
		virtual ~Curve();
		
		//! Sets the curve of segment
		/*!
		 * if 0, a straight line is produced. If non-zero:
		 * here is a slowly rising, fast decaying (convex) 
		 * curve, while if itype < 0, the curve is 
		 * fast rising, slowly decaying (concave)
		 * The following curve, for dur steps:
		 *
		 * _start + (_end - _start) * (1 - exp( _phi*_curve/(n-1) )) / (1 - exp(_curve));
		 *
		 * Part of Csound as "transeg opcode" 
		 * Author: John ffitch
		 * University of Bath, Codemist. Ltd.
		 * Bath, UK
		 * October, 2000
		 */
		void setCurve(const AudFloat &type=.0001);
		
	protected:
		//! Processing the audio sample
		/*!
		 * The forwards the call to Phasor: Processing(), the value is in the range (start, end).
		 * furthermore, the segment is curved by setCurve()
		 */
		virtual void Processing();
		
	private:
		AudFloat _curve;
	};
} //	end of namespace Aud
#endif
///EOF
