/***************************************************/
/*! \class Gaussian
 \brief
 
 The AudioDrome Random class, implements a 
 Gaussian distribution random number generator.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef GAUSSIAN_H
#define GAUSSIAN_H

#include "Random.h"

//  begin namespace
namespace Aud
{
	class Gaussian : public Random
		{
		public:
			//! Public constructor
			/*!
			 * If the "seed" is "true" (default), initializes the 
			 * object with the current time, each Random-object, 
			 * can be produce an arbitrary sets of values.
			 * Otherwise the Random-generator, always produces 
			 * the same set of values for each object created.			 
			 */
			Gaussian(const AudFloat &amplitude=1, const AudFloat &sigma=1, const bool &seed=true);
			
			//! Public destructor
			virtual ~Gaussian();
			
		protected:
			//! Processing the audio sample
			/*!
			 * Gaussian distribution random number generator.
			 * Polar Box-Muller (1958) method; See Knuth v2, 3rd ed, p122.
			 * http://en.wikipedia.org/wiki/Box-Muller_transform
			 * http://www.bearcave.com/misl/misl_tech/wavelets/hurst/random.html
			 */
			virtual void Processing();
			
		private:
			double _x, _y, _r2;
			void setPolarity(const POLARITY &polar);
		};
} //	end of namespace Aud
#endif
///EOF
