/***************************************************/
/*! \class HoldRandom
 \brief
 
 The AudioDrome HoldRandom class, inherits from Random.
 Like the Random class, can be unipolar or bipolar.
 but the last value is kept until the next generation
 The frequency of extraction, expressed by the parameter 
 "band", rule the spectral band width of signal. 
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef HOLDRANDOM_H
#define HOLDRANDOM_H

#include "Random.h"
#include "Metronome.h"

//  begin namespace
namespace Aud
{
	class HoldRandom : public Random
		{
		public:
			//! Public constructor
			/*!
			 * If the "seed" is "true" (default), initializes the 
			 * object with the current time, each Random-object, 
			 * can be produce an arbitrary sets of values.
			 * Otherwise the Random-generator, always produces 
			 * the same set of values for each object created.			 
			 */
			HoldRandom(const AudFloat &amplitude=1, 
					   const AudFloat &freq=440,
					   const POLARITY &polar=BIPOLAR, 
					   const bool &seed=true);
			
			//! Public destructor
			virtual ~HoldRandom();
			
			//! Sets the spectral band width of signal
			/*!
			 * This parameter expressed in Hz, 
			 * rule the spectral width of resulting signal.
			 */
			void setFrequency(const AudFloat &freq=440)
			{
				_extract.setFrequency(freq);
			}
			
		protected:
			//! Processing the audio sample
			/*!
			 * The "psuedo-random" value, is uniformly distribuited
			 * frome the range -range to +range.
			 * The spectral band of signal, depends on the generating numbers frequency.
			 * The last value is maintained until the next generation.
			 */
			virtual void Processing();
			
			Metronome _extract;
		};
} //	end of namespace Aud
#endif
///EOF

