/***************************************************/
/*! \class InterpRandom
 \brief
 
 The AudioDrome InterpRandom class, inherits from HoldRandom.
 Like the Random class, can be unipolar or bipolar.
 but the sample is linearly interpolated with the next value.
 The frequency of extraction, expressed by the parameter
 "band", rule the spectral band width of signal. 
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef INTERPRANDOM_H
#define INTERPRANDOM_H

#include "Random.h"
#include "Line.h"

//  begin namespace
namespace Aud
{
	class InterpRandom : public Random
		{
		public:
			//! Public constructor
			InterpRandom(const AudFloat &amplitude=1, 
						 const AudFloat &freq=440,
						 const POLARITY &polar=BIPOLAR, 
						 const bool &seed=true);
			
			//! Public destructor
			virtual ~InterpRandom();
			
			//! Sets the spectral band width of signal
			/*!
			 * This parameter expressed in Hz, 
			 * rule the spectral width of resulting signal.
			 */
			void setFrequency(const AudFloat &freq=440)
			{
				_rampa.setFrequency(freq);
			}
			
		protected:
			//! Processing the audio sample
			/*!
			 * The "psuedo-random" value, is uniformly distribuited
			 * frome the range -range to +range.
			 * The spectral band of signal, depends on the generating numbers frequency.
			 * The last value is linearly interpolated with the next value.
			 */
			virtual void Processing();
			
		private:
			Line _rampa;
		};
} //	end of namespace Aud
#endif
///EOF
