/***************************************************/
/*! \class Interpolation
 \brief
 
 The AudioDrome Interpolation class, implements a 
 linear interpolation between two input signals.
 And converts a control signal to an audio signal 
 using linear interpolation.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef INTERPOLATION_H
#define INTERPOLATION_H

#include "AudioDrome.h"

//  begin namespace
namespace Aud
{
	class Interpolation : public AudioDrome
		{
		public:
			//! Public constructor
			Interpolation();
			
			//! Public destructor
			virtual ~Interpolation();
			
			//! Sets the point of interpolation between the two audio samples
			/*!
			 * They are allowed values between 0 and 1, with zero value is returned "sig1", 
			 * a value as 1, is entirely returned "sig2" and intermediate values return a mixing weighed of values. 
			 * Present in Csound as "ntrpol opcode" to Gabriel Maldonado.			 
			 */
			void setInterpolationPoint(const AudFloat &point);
			
			//! Sets the input value one
			void setValue1(const AudFloat &val1);
			
			//! Sets the input value two
			void setValue2(const AudFloat &val2);
			
			//! Sets the all parameters
			/*!
			 * Is the same to use setValue1(), setValue2() and setInterpolationPoint():
			 */
			void setParameters(const AudFloat &val1, const AudFloat &val2,const AudFloat &point);
			
		protected:
			//! Processing the audio sample
			virtual void Processing();
			
		private:
			AudFloat _val1;
			AudFloat _val2;
			AudFloat _point;
		};
} //	end of namespace Aud
#endif
///EOF
