/***************************************************/
/*! \class LP_Butterworth Filter
 \brief
 
 The AudioDrome LP_Butterworth class, implements a 
 low-pass Butterworth filter. 
 Coded by Paris Smaragdis 1994
 
 Csound's code butter.c
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef LP_BUTTERWORTH_H_
#define LP_BUTTERWORTH_H_

#include "AudioDrome.h"

#define ROOT2 (1.4142135623730950488)

//  begin namespace
namespace Aud
{
	class LP_Butterworth : public AudioDrome
		{
		public:
			//! Public constructor
			LP_Butterworth(const AudFloat &cutOff=5000);
			
			//! Publid destructor
			virtual ~LP_Butterworth();
			
			//! Sets the cut-off frequency, in Hz
			virtual void setCutOff(const AudFloat &cutOff=5000); /*! Sampling Rate Change SLOT */
			
		protected:
			//! Processing the audio sample
			virtual void Processing();
			
			inline void calcCoefs() /*! Sampling Rate Change SLOT */
			{
				_pidsr = (AudFloat)M_PI / _localSR; /* Constant really */
			}
			
			virtual void srUpdate()
			{ 
				this->calcCoefs(); //! must be first called
				this->setCutOff(_cutOff);
			}
			
			AudFloat* _coeff;
			AudFloat _pidsr;
			AudFloat _cutOff;
		};
} //	end of namespace Aud
#endif /*LP_BUTTERWORTH_H_*/
///EOF
