/***************************************************/
/*! \class Curve
 \brief
 
 The AudioDrome Line class, constructs only a segment
 between two points expressed like "start, end".
 The segment duration is expressed in seconds and 
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef LINE_H
#define LINE_H

#include "Phasor.h"

//  begin namespace
namespace Aud
{
	class Line : public Phasor
		{
		public:
			//! Public constructor
			Line();
			
			//! Public destructor
			virtual ~Line();
			
			//! Sets the time duration in seconds of segment
			virtual void setTime(const AudFloat &time);
			
			//! Sets the beginning value of segment
			void setStartValue(const AudFloat &start=0);
			
			//! Sets the final value of the segment
			void setEndValue(const AudFloat &end=1);
			
			//! Trigger a new segment with the same values
			/*
			 * If the function is called when a segment is running, 
			 * This will be interrupted and restarting.			 
			 */
			inline void trigger()
			{
				Phasor::trigger();
				_trigger = false;
			}
			
		protected:
			//! Processing the audio sample
			/*!
			 * This funcion calls Phasor::Processing(), the value is normalized 
			 * within the range (start, end).			 
			 */
			virtual void Processing();
			
			AudFloat _start;
			AudFloat _end;
			AudFloat _range;
		};
} //	end of namespace Aud
#endif
///EOF
