/***************************************************/
/*! \class LowPass Filter
 \brief
 
 The AudioDrome LowPass class, implements a first-order filter.
 
 Csound's code, based on Robin Whittle's
 ugrw2.c and ugrw2.h of 9 September 1995
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef LOWPASS_H
#define LOWPASS_H

#include "AudioDrome.h"

//  begin namespace
namespace Aud
{
	class LowPass : public AudioDrome
		{
		public:
			//! Public constructor
			LowPass(const AudFloat &cutOff=500);
			
			//! Public destructor
			virtual ~LowPass();
			
			//! Sets the cut-off frequency
			void setCutOff(const AudFloat &cutOff); /*! Sampling Rate Change SLOT */
			
		protected:
			//! Processing the audio sample
			virtual void Processing();
			
		protected:
			AudFloat _c1;
			AudFloat _c2;
			AudFloat _yt1;
			AudFloat _cutOff;
			
			virtual void srUpdate()
			{ 
				this->setCutOff(_cutOff);
			}
		};
} //	end of namespace Aud
#endif
///EOF

