/***************************************************/
/*! \class Wave
 \brief
 
 The AudioDrome Wave is a specialization of Buffer.
 Mainly methods of this class, are used to generate 
 prototypal Waveform
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef WAVE_H
#define WAVE_H

#include "Buffer.h"

//  begin namespace
namespace Aud
{
	class Wave : public Buffer
		{
		public:
			//! Public constructor
			/*!
			 * Initialize the object with an integer value for the size of the array. 
			 * Memory is allocated dynamically.
			 */
			Wave(const unsigned long &length=4096, const WAVESHAPE& type=SINE);
			
			//! Public conversion constructor: Buffer <- Wave
			Wave(const Buffer& x) : Buffer(x)
			{
#if __DEBUG__
				std::cout << "====> Conversion Constructor of: Buffer <- Wave " << this << std::endl;
#endif
				//this->copy(x);
			}
			
			//! Public destructor
			virtual ~Wave();
			
			//! Generate a sine wave
			void genSine();
			
			//! Generate a cosine wave
			void genCosine();
			
			//! Generate a square wave
			void genSquare();
			
			//! Generate a sawtooth wave
			void genSaw();
			
			//! Generate a triangular wave
			void genTriangle();
			
			//! Generate a sigmoid waveform
			void genSigmoid();
			
			//! Generate a double sigmoid waveform
			void genDoubleSigmoid();
			
			//! Adds a sinusoidal partial to the prototype
			/*!
			 * This procedure generates and adds a partial sinusoidal 
			 * in the table. Each harmonic is weighed 
			 * in amplitude, frequency and phase.			 
			 */
			void genArm(const unsigned int &numArm, const AudFloat &ampArm,
						const AudFloat &phArm=0, const AudFloat &offSet=0);
		};
} //	end of namespace Aud (GenUnit)
#endif
///EOF
