/***************************************************/
/*! \class Window
 \brief
 
 The AudioDrome Window is a specialization of Buffer.
 Mainly methods of this class, are used to generates
 functions of different windows.
 These windows are usually used for spectrum analysis or 
 for grain envelope.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifndef WINDOW_H
#define WINDOW_H

#include "Buffer.h"

//  begin namespace
namespace Aud
{
	class Window : public Buffer
		{
		public:
			//! Public constructor
			/*!
			 * Initialize the object with an integer value for the size of the array. 
			 * Memory is allocated dynamically.
			 */
			Window(unsigned int length=4096, const WINDOWS& type=GAUSSIAN);
			
			//! Costruttore di conversione di Buffer <- Window
			Window(const Buffer& x) : Buffer(x)
			{
#if __DEBUG__
				std::cout << "====> Conversion Constructor of: Buffer <- Window " << this << std::endl;
#endif
				//this->copy(x);		
			}
			
			//! Public destructor
			virtual ~Window();
			
			//! Generate a rectangular window
			void Window::genRectangular();
			
			//! Generate a Barlett window (triangular).
			void genBarlett();
			
			//! Generate a Gaussian window
			void genGaussian();
			
			//! Generate a Hanning window
			void genHanning();
			
			//! Generate a Hamming window
			void genHamming();
			
			//! Generate a Blackman window
			void genBlackman();
			
			//! Generate a Blackman-Harris window
			void genBlackmanHarris();
			
			//! Generate a Barlett-Hanning window
			void genBarlettHanning();
			
			//! Generate a Nuttall window
			void genNuttall();
			
			//! Generate a Sync window
			/*!
			 * The value 0.75 (default) refers to the magnitude of the prototype, 
			 * while the "SYNC" signal is always 1.0. 
			 * This is emitted at center of window: namely "_size / 2".
			 */
			void genSync(const AudFloat &value=.75);
		};
} //	end of namespace Aud
#endif
///EOF
