/***************************************************/
/*! \class AllPass
 \brief
 
 The AudioDrome AllPass class, 
 implements a IIR-filter (infinite impule response filter).
 
 * ===================================================
 * 		    ____________ -g __________
 * 		   |                          |
 *  input --- + --[..... d.....] ----- + --- Processing()
 * 	         |_________ g ________|
 * ===================================================
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "AllPass.h"

using namespace Aud; 

namespace Aud
{
	
	AllPass::AllPass(const AudFloat &delayMax, const INTERPOLATION& type) :
	Comb(delayMax, type)
	{
#if __DEBUG__
		std::cout << "AllPass Filter Constructor: "<< this<<std::endl;
#endif
		_out = _sampleHold = 0.0;
	}
	
	AllPass::~AllPass()
	{
#if __DEBUG__
		std::cout << "AllPass Filter Destructor: "<< this<<std::endl;
#endif
	}
	
}

void AllPass::Processing()
{
	/* allpass network (a.k.a. allpass filter) as documented by F. Richard Moore */
	
	_sampleHold = _input_1;
	_input_1 =  _sampleHold + (_out * _gain);

	DelayTaps::Processing();
	
	_out = _output_1; 
	_output_1 = (_sampleHold * -_gain) + (_out * ( 1.0 - pow((double)_gain, 2.0)));
	
} //	end of namespace Aud
///EOF
