/***************************************************/
/*! \class AudioDrome
 \brief
 
 N.B. BSD/Allman[built.in]
 
 The AudioDrome base class, contains statics methods and global declarations.
 
 AudioDrome is a "open sources" c++ classes collection.
 Each class is the abstraction of an primitive DSP (Digital Signal Processing) algorithm.
 AudioDrome is conceived with a open structure, simple and extensible interface.
 This c++ "namespace" is addressed to software developers and researchers in the digital-sound domain.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "AudioDrome.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	AudFloat AudioDrome::_absoluteSR = 44100.0f;
	
	std::vector<AudioDrome*> AudioDrome::_objectList;
	
	AudioDrome::AudioDrome() : _localSR(44100.0f),
	_input_1(0), _output_1(0), _input_2(0), _output_2(0)
	{
#if __DEBUG__
		std::cout << "AudioDrome Constructor: " << this << std::endl;
		std::cout << DataType << std::endl;
#endif
		_objectList.push_back(this);
		
		this->setDownSampling();
		_smplCount = 0;
	}
	
	AudioDrome::~AudioDrome()
	{
#if __DEBUG__
		std::cout << "AudioDrome Destructor: " << this <<std::endl;
#endif		
		for(int i = 0; i < _objectList.size(); i++)
			if (_objectList[i] == this)
				_objectList.erase(_objectList.begin()+i);		
	}
	
	bool AudioDrome::isBigEndian()
	{
		//		unsigned int temp1 = 1;
		//		unsigned char *temp2 = (unsigned char*) &temp1;
		//		return (*temp2 ? false : true);
		
		short word = 0x4321;
		if((*(char *)& word) != 0x21 )
			return true;
		else 
			return false;
	}
	
	void AudioDrome::printEndianType()
	{
		std::cout << "Computer architecture is: ";
		if (AudioDrome::isBigEndian())
			std::cout << "Big Endian.";
		else
			std::cout << "Little Endian (or other non-Big Endian).";
		std::cout << std::endl;
	}
	
	void AudioDrome::setAbsoluteSR(const AudFloat &sr)  /*! Sampling Rate Change SIGNAL */
	{
		if(sr > 0 && sr != _absoluteSR)
		{
			_absoluteSR = sr;
			for(int i = 0; i < _objectList.size(); i++)
			{
				_objectList[i]->setDownSampling( _objectList[i]->getDownSampling() );
				//				_objectList[i]->srUpdate();
			}
		}
	}
	
	void AudioDrome::setDownSampling(const ul& samples) /*! Sampling Rate Change SIGNAL */
	{
		_smplBlock = (samples >= 1 ? samples : 1);
		_localSR = AudioDrome::getAbsoluteSR() / _smplBlock;
		this->srUpdate();
	}	
	
	AudFloat AudioDrome::getAbsoluteNyquist()
	{
		return getAbsoluteSR() / 2.0;
	}
	
	AudFloat AudioDrome::dbRaw(const AudFloat &input)
	{
		return (AudFloat)(log(fabs((double)input)) / (0.11512925));
	}
	
	AudFloat AudioDrome::rawDb(const AudFloat &input)
	{
		return (AudFloat)exp((double)input * (0.11512925));
	}
	
	AudFloat AudioDrome::semitone(const AudFloat &stone)
	{
		AudFloat resc = stone * (0.08333333333333333333333);
		return pow(2.0, resc);
	}
	
	AudFloat AudioDrome::cents(const AudFloat &cnt)
	{
		AudFloat resc = cnt * (0.00083333333333333333333);
		return pow(2.0, resc);
	}
	
} //	end of namespace Aud
///EOF

