/***************************************************/
/*! \class AudioIn
 \brief
 
 The AudioDrome AudioIn class, is a wrapper
 for the PortAudio_v19 pa_stable_v19_20071207
 by Ross Bencina
 
 This class are not affected by _absoluteSR changing notification,
 in fact the hardware audio stream, or VST (RTAS o AUDIOUNIT) sampling rate in a host
 system, is considered like _absoluteSR value.
 
 $Id: portaudio.h 1247 2007-08-11 16:29:09Z rossb $
 PortAudio Portable Real-Time Audio Library
 PortAudio API Header File
 Latest version available at: http://www.portaudio.com/
 
 Copyright (c) 1999-2002 Ross Bencina and Phil Burk
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#ifdef __WITH_PORTAUDIO__
#include "AudioOut.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	AudioOut::AudioOut(const PaDeviceIndex &device, 
					   const int &chnls,
					   const unsigned long &framesPerBuffer,
					   const PaSampleFormat &smpFormat,
					   const PaStreamFlags &flags,
					   const bool &openStarted)
	: AudioIO(chnls, framesPerBuffer, smpFormat, flags), _indexBufWrite(0)
	{
#if __DEBUG__
		std::cout << "AudioOut Constructor: "<< this<<std::endl;
#endif
		this->setParameters(device, chnls, smpFormat);

		if(openStarted)
		{
			this->openStream();
			this->startStream();
		}
	}
	
	AudioOut::~AudioOut()
	{
#if __DEBUG__
		std::cout << "AudioOut Destructor: "<< this<<std::endl;
#endif
	}
	
	void AudioOut::openStream()  /*! Sampling Rate Change SLOT */
	{
		bool start = false;	
		
		if( this->isStreamStarted() )
		{
			this->stopStream();
			start = true;
		}
		if( this->isStreamOpened() )
			this->closeStream();
		
		/* Open an audio Output stream. */
		_err = Pa_OpenStream( &_stream,
							 NULL,
							 &_parameters,
							 AudioDrome::getAbsoluteSR(),
							 _framesPerBuffer,
							 _streamFlags,
							 _streamCallback,
							 _data );					
		
		if( _err != paNoError )
			this->portAudioError( "AudioIO::openStream()" );
		_isOpened = true;
		
		if(start)
			this->startStream();
	}
	
	void AudioOut::Processing()
	{
		_buffer[_indexBufWrite] = (PaFloat) _input_1;
		_buffer[++_indexBufWrite]= (PaFloat) _input_2;
		
		if (++_indexBufWrite >= _samplesBuffer)
		{
			_indexBufWrite = 0;
			_err = Pa_WriteStream(_stream, _buffer, _framesPerBuffer );
			//			if (_err != paNoError )
			//				this->portAudioError( "AudioIO::putSignal()" );
		}		
	}
} //	end of namespace Aud
#endif
///EOF
