/***************************************************/
/*! \class BR_Butterworth BandReject Filter
 \brief
 
 The AudioDrome BR_Butterworth class, implements a 
 band-reject Butterworth filter. 
 Coded by Paris Smaragdis 1994
 
 Csound's code butter.c
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "BR_Butterworth.h"
#include <iostream>

using namespace Aud; 

//  begin namespace
namespace Aud
{
	BR_Butterworth::BR_Butterworth(const AudFloat &centerFreq,
								   const AudFloat &bandWidth) :
	BP_Butterworth(centerFreq, bandWidth)
	{
#if __DEBUG__
		std::cout << "Butterworth BandReject Filter Constructor: "<< this <<std::endl;
#endif
	}
	
	BR_Butterworth::~BR_Butterworth()
	{
#if __DEBUG__
		std::cout << "Butterworth BandReject Filter Destructor: "<< this <<std::endl;
#endif
	}
	
	void BR_Butterworth::setCenterFrequency(const AudFloat &centerFreq)
	{
		_cf = centerFreq;
		AudFloat c, d;
		c = (AudFloat)tan((double)(_pidsr * _bw));
		d = 2.0 * (AudFloat)cos( 2.0 * (double)(_pidsr * _cf));
		_coeff[1] = 1.0 / (1.0 + c);
		_coeff[2] = -d * _coeff[1];
		_coeff[3] = _coeff[1];
		_coeff[4] = _coeff[2];
		_coeff[5] = (1.0 - c) * _coeff[1];
	}
	
	void BR_Butterworth::setBrBandWidth(const AudFloat &bandWidth)
	{
		_bw = bandWidth;
		this->setCenterFrequency(_cf);
	}
} //	end of namespace Aud
///EOF
