/***************************************************/
/*! \class BlockerDc
 \brief
 
 The AudioDrome BlockerDc class, implements a recoursive filter DC blocker.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "BlockerDc.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	BlockerDc::BlockerDc()
	{
#if __DEBUG__
		std::cout << "BlockerDc Constructor: "<< this<<std::endl;
#endif
		_pos = 0.f;
		_speed = 0.f;
		_sample = 0.f;
		_oldInput = 0.f;
		_oldOutput = 0.f;
		this->setGain (0.995);
		this->setAlgorithm(NORMAL);
	}
	
	BlockerDc::~BlockerDc()
	{
#if __DEBUG__
		std::cout << "BlockerDc Destructor: "<< this<<std::endl;
#endif
	}
	
	void BlockerDc::setGain(const AudFloat& gain)
	{
		_gain = gain;
	}
	
	void BlockerDc::Processing()
	{
		_output_1 = (this->*_modePtr)(_input_1);
	}
	
	AudFloat BlockerDc::normal(const AudFloat& input)
	{
		_sample = input - _oldInput + (_gain * _oldOutput);
		_oldInput = input;
		_oldOutput = _sample;
		return _sample;
	}
	
	AudFloat BlockerDc::gst(const AudFloat& input)
	{
		///Ross Bencina (RB-GST).
		_speed += (input - _pos) * 0.000004567f;
		_pos += _speed; ///_pos = _pos + _speed;
		_speed *= 0.96f; ///_speed = _speed * 0.96f;
		return input - _pos;
	}
} //	end of namespace Aud
///EOF
