/***************************************************/
/*! \class BreakLine
 \brief
 
 The AudioDrome BreakLine class, constructs of the segments 
 between two points expressed like Time-value. 
 The segments assume a specific curving through setCurve(). 
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "BreakLine.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	BreakLine::BreakLine() : _index(2), _endOfBreakPoints(false)
	{
#if __DEBUG__
		std::cout << "BreakLine Constructor: " << this <<std::endl;
#endif
		this->setStartValue(0.0);
		this->enableWrapAround(false);
	}
	BreakLine::~BreakLine()
	{
#if __DEBUG__
		std::cout << "BreakLine Destructor: " << this <<std::endl;
#endif
	}
	
	void BreakLine::addBreakPoint(const AudFloat &time, const AudFloat &value)
	{
		if (fabs(time) > 0)
		{
			_brkPoint.push_back(time);
			_brkPoint.push_back(value);
			
			if (_brkPoint.size() == 2)
			{
				Line::setTime(_brkPoint.at(0));
				Line::setEndValue(_brkPoint.at(1));
			}
		}
	}
	
	void BreakLine::removeLastBreakPoint()
	{
		if(!_brkPoint.empty())
		{
			_brkPoint.pop_back();//time
			_brkPoint.pop_back();//value
		}
		if(_brkPoint.size() < 2)
			this->clearAllBreakPoints();
	}
	
	void BreakLine::setStartValue(const AudFloat &start)
	{
		_first = start;
		Line::setStartValue(start);
	}
	
	void BreakLine::clearAllBreakPoints()
	{
		_brkPoint.clear();
		Line::setTime(0);
		Line::setStartValue(0);
		Line::setEndValue(0);
	}
	
	
	void BreakLine::Processing()
	{
		breakPoint();
		Line::Processing();
	}
	
	void BreakLine::breakPoint()
	{
		_endOfBreakPoints = false;
		if (Phasor::_trigger)//for every segment
		{
			if (_index < _brkPoint.size())//update the values
			{
				Line::setStartValue(_end);
				Line::setTime(_brkPoint.at(_index));
				Line::setEndValue(_brkPoint.at(++_index));
				++_index;
			}
			else if(!_mode)//if loop mode is disabled
			{
				//				_endOfBreakPoints = true;
				_index = _brkPoint.size();
			}
			else//se in modalità loop
			{
				_endOfBreakPoints = true;
				_index = 2;
				if(!_brkPoint.empty())
				{
					Line::setStartValue(_first);
					Line::setTime(_brkPoint.at(0));
					Line::setEndValue(_brkPoint.at(1));
				}
			}
		}
	}
} //	end of namespace Aud
///EOF
