/***************************************************/
/*! \class Comb
 \brief
 
 The AudioDrome Comb class, 
 implements a IIR-filter (infinite impulse response filter).
 
 * ===================================================
 *  input -- + -[..... d.....] --------- out delay 2
 * 	        |________ g ________|
 * ===================================================
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Comb.h"

using namespace Aud; 

namespace Aud
{
	
	Comb::Comb(const AudFloat &delayMax, const INTERPOLATION& type) :
	DelayTaps(delayMax, type)
	{
#if __DEBUG__
		std::cout << "Comb Filter Constructor: "<< this <<std::endl;
#endif
		_t60 = 0.0;
	}
	
	Comb::~Comb()
	{
#if __DEBUG__
		std::cout << "Comb Filter Destructor: "<< this <<std::endl;
#endif
	}
	
	void Comb::setT60(const AudFloat& t60)
	{
		_t60 = t60;
		_gain = pow(10.0, (double)(-3.0 * _delayTime) / _t60);
		//	_gain = (AudFloat) exp((double)(log(.001) * _delayTime / _t60)); /* Csound Code */ 	
	}
	
	void Comb::setGain(const AudFloat& gain)
	{
		_gain = gain;
		
		if (_gain >= 1.0)
			_gain = 0.9999;
		else if (_gain <= 0.0)
			_gain = 0.0001;
		
		_t60 = 3.0 * _delayTime / log10((double)1.0 / (double)_gain);
	}
	
	void Comb::Processing()
	{
		/* CSOUND IMPLEMENTATION
		 anodo   init 0 
		 aout    init 0  
		 asig linseg 1, 1/kr,0, p3-(1/kr), 0  
		 kt60 = 3						;Time duration in seconds (reverberation length)
		 kdel = .1						;Delay time in seconds
		 kg kpow 10, (-3*kdel)/kt60		;Calculate gain
		 a1 delayr 5					;5 = Max delay of delay Line
		 anodo =  asig + (aout*kg)
		 aout deltapi kdel		
		 delayw anodo
		 out aout*10000 
		 */
		
		/* Non ritorna l'input */
		_input_1 = _input_1 + (_output_1 * _gain);

		DelayTaps::Processing();
		
		/* Get the imput */
		//AudFloat nodo = _input_1 + (_out * _gain);
//		_out = DelayTaps::Processing( nodo);
//		_output_1 = nodo;
	}
} //	end of namespace Aud
///EOF
