/***************************************************/
/*! \class Curve
 \brief
 
 The AudioDrome Curve class, constructs only a segment
 between two points expressed like "start, end".
 The segment duration is expressed in seconds and 
 the segment can be assume a specific curving through setCurve()
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Curve.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	Curve::Curve() : _curve(0.001)
	{
#if __DEBUG__
		std::cout << "Curve Constructor: " << this <<std::endl;
#endif
	}
	
	Curve::~Curve()
	{
#if __DEBUG__
		std::cout << "Curve Destructor: " << this <<std::endl;
#endif
	}
	
	void Curve::setCurve(const AudFloat &type)
	{
		_curve = (type == 0 ? 0.001 : type);
	}
	
	void Curve::Processing()
	{
		if (Phasor::_trigger)
		{
			_output_1 = _end;
		}
		else
		{
			Phasor::Processing();
			_output_1 = _start + (1.0 - exp ((double)_output_1 * _curve )) / (1.0 - exp ((double)_curve)) * _range;
		}
	}
} //	end of namespace Aud
///EOF

