/***************************************************/
/*! \class Gaussian
 \brief
 
 The AudioDrome Random class, implements a 
 Gaussian distribution random number generator.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Gaussian.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	Gaussian::Gaussian(const AudFloat &amplitude, const AudFloat &sigma, const bool &seed) 
	: Random(amplitude, BIPOLAR, seed), _x(0), _y(0), _r2(0)
	{
#if __DEBUG__
		std::cout << "Gaussian Constructor: "<< this<<std::endl;
#endif
	}
	
	Gaussian::~Gaussian()
	{
#if __DEBUG__
		std::cout << "Gaussian Destructor: "<< this<<std::endl;
#endif
	}
	
	void Gaussian::Processing()
	{
		do
		{
			/* choose x,y in uniform square (-1,-1) to (+1,+1) */
			_x = this->bipolar(1.0);
			_y = this->bipolar(1.0);
			/* see if it is in the unit circle */
			_r2 = _x * _x + _y * _y;
		} while (_r2 > 1.0 || _r2 == 0);
		
		/* Box-Muller transform */
		_output_1 = (AudFloat) _amplitude * _y * sqrt (-2.0 * log ((double)_r2) / _r2);
	}
} //	end of namespace Aud
///EOF
