/***************************************************/
/*! \class HP_Butterworth Filter
 \brief
 
 The AudioDrome HP_Butterworth class, implements a 
 high-pass Butterworth filter. 
 Coded by Paris Smaragdis 1994
 
 Csound's code butter.c
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "HP_Butterworth.h"
#include <iostream>

using namespace Aud; 

//  begin namespace
namespace Aud
{
	HP_Butterworth::HP_Butterworth(const AudFloat &cutOff) :
	LP_Butterworth(cutOff)
	{
#if __DEBUG__
		std::cout << "Butterworth HighPass Filter Constructor: "<< this <<std::endl;
#endif
	}
	
	HP_Butterworth::~HP_Butterworth()
	{
#if __DEBUG__
		std::cout << "Butterworth HighPass Filter Destructor: "<< this <<std::endl;
#endif
	}
	
	void HP_Butterworth::setCutOff(const AudFloat &cutOff)
	{
		AudFloat c;
		c = (AudFloat)tan((double)(_pidsr * cutOff));
		_coeff[1] = 1.0 / ( 1.0 + ROOT2 * c + c * c);
		_coeff[2] = -(_coeff[1] + _coeff[1]);
		_coeff[3] = _coeff[1];
		_coeff[4] = 2.0 * (c*c - 1.0) * _coeff[1];
		_coeff[5] = ( 1.0 - ROOT2 * c + c * c) * _coeff[1];
	}
} //	end of namespace Aud
///EOF
