/***************************************************/
/*! \class HighPass Filter
 \brief
 
 The AudioDrome HighPass class, implements a first-order filter.
 
 Csound's code, based on Robin Whittle's
 ugrw2.c and ugrw2.h of 9 September 1995
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "HighPass.h"

using namespace Aud; 

namespace Aud
{
	
	HighPass::HighPass(const AudFloat &cutOff) :
	LowPass(cutOff)
	{
#if __DEBUG__
		std::cout << "HighPass Filter Constructor: "<< this <<std::endl;
#endif
	}
	
	HighPass::~HighPass()
	{
#if __DEBUG__
		std::cout << "HighPass Filter Destructor: "<< this <<std::endl;
#endif
	}
	
	void HighPass::Processing()
	{
		/* 
		 Filter calculation on each a rate sample:
		 New state =   (c2 * old state) + (c1 * input value)               
		 */
		_output_1 = _yt1 = _c2 * (_yt1 + _input_1);
		_yt1 -= _input_1;
	}
} //	end of namespace Aud
///EOF
