/***************************************************/
/*! \class InterpRandom
 \brief
 
 The AudioDrome InterpRandom class, inherits from HoldRandom.
 Like the Random class, can be unipolar or bipolar.
 but the sample is linearly interpolated with the next value.
 The frequency of extraction, expressed by the parameter
 "band", rule the spectral band width of signal. 
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "InterpRandom.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	InterpRandom::InterpRandom(const AudFloat &amplitude, 
							   const AudFloat &freq,
							   const POLARITY &polar, 
							   const bool &seed) : Random(amplitude, polar, seed)
	{
#if __DEBUG__
		std::cout << "InterpRandom Constructor: "<< this<<std::endl;
#endif
		_rampa = Line();
		this->setFrequency(freq);
	}
	
	InterpRandom::~InterpRandom()
	{
#if __DEBUG__
		std::cout << "InterpRandom Destructor: "<< this<<std::endl;
#endif
	}
	
	void InterpRandom::Processing()
	{
		_rampa.PROCESSING();
		if (_rampa.Output())
		{
			_rampa.PROCESSING();
			_rampa.setStartValue(_rampa.Output());
			Random::Processing();
			_rampa.setEndValue(_output_1);
		}
		_rampa.PROCESSING();
		_output_1 = _rampa.Output();
	}
} //	end of namespace Aud
///EOF
