/***************************************************/
/*! \class Interpolation
 \brief
 
 The AudioDrome Interpolation class, implements a 
 linear interpolation between two input signals.
 And converts a control signal to an audio signal 
 using linear interpolation.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Interpolation.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	Interpolation::Interpolation() :
	_val1(0), _val2(0), _point(0)
	{
#if __DEBUG__
		std::cout << "Interpolation Construct: "<< this<<std::endl;
#endif
	}
	
	Interpolation::~Interpolation()
	{
#if __DEBUG__
		std::cout << "Interpolation Destruct: "<< this<<std::endl;
#endif
	}
	
	void Interpolation::setInterpolationPoint(const AudFloat &point)
	{
		_point = (point< 0 || point > 1 ? 0 : point);
	}
	
	void Interpolation::setValue1 (const AudFloat &val1)
	{
		_val1 = val1;
	}
	
	void Interpolation::setValue2 (const AudFloat &val2)
	{
		_val2 = val2;
	}
	
	void Interpolation::setParameters(const AudFloat &val1, const AudFloat &val2, const AudFloat &point)
	{
		this->setValue1(val1);
		this->setValue2(val2);
		this->setInterpolationPoint(point);
	}
	
	void Interpolation::Processing()
	{
		_output_1 = _point * (_val2 - _val1) + _val1;
	}
} //	end of namespace Aud
///EOF
