/***************************************************/
/*! \class LP_Butterworth Filter
 \brief
 
 The AudioDrome LP_Butterworth class, implements a 
 low-pass Butterworth filter. 
 Coded by Paris Smaragdis 1994
 
 Csound's code butter.c
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "LP_Butterworth.h"
#include <iostream>

using namespace Aud; 

//  begin namespace
namespace Aud
{
	LP_Butterworth::LP_Butterworth(const AudFloat &cutOff) : _cutOff(cutOff)
	{
#if __DEBUG__
		std::cout << "Butterworth LowPass Filter Constructor: "<< this <<std::endl;
#endif
		this->calcCoefs();
		_coeff = new AudFloat[10];
		for (unsigned short i = 0; i < 10; i++)
			_coeff[i] = 0.0;
		this->setCutOff(cutOff);
	}
	
	LP_Butterworth::~LP_Butterworth()
	{
#if __DEBUG__
		std::cout << "Butterworth LowPass Filter Destructor: "<< this <<std::endl;
#endif
		delete _coeff;
	}
	
	void LP_Butterworth::setCutOff(const AudFloat &cutOff) /*! Sampling Rate Change SLOT */
	{
		_cutOff = cutOff;
		AudFloat c;
		c = (AudFloat) 1.0 / fabs(tan((double)(_pidsr * _cutOff))); /* without fabs does not work correctly*/
		//		c = (AudFloat) 1.0 / tan((double)(_pidsr * _cutOff));
		_coeff[1] = 1.0 / ( 1.0 + ROOT2 * c + c * c);
		_coeff[2] = _coeff[1] + _coeff[1];
		_coeff[3] = _coeff[1];
		_coeff[4] = 2.0 * ( 1.0 - c*c) * _coeff[1];
		_coeff[5] = ( 1.0 - ROOT2 * c + c * c) * _coeff[1];
	}
	
	void LP_Butterworth::Processing()
	{
		AudFloat t;
		t = _input_1 - _coeff[4] * _coeff[6] - _coeff[5] * _coeff[7];
		_output_1 = t * _coeff[1] + _coeff[2] * _coeff[6] + _coeff[3] * _coeff[7];
		_coeff[7] = _coeff[6];
		_coeff[6] = t;
		//		_output_1 = y;
	}
} //	end of namespace Aud
///EOF
