/***************************************************/
/*! \class Curve
 \brief
 
 The AudioDrome Line class, constructs only a segment
 between two points expressed like "start, end".
 The segment duration is expressed in seconds and 
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Line.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	Line::Line() : _start(0), _end(1), _range(1)
	{
#if __DEBUG__
		std::cout << "Line Constructor: " << this <<std::endl;
#endif
	}
	
	Line::~Line()
	{
#if __DEBUG__
		std::cout << "Line Destructor: " << this <<std::endl;
#endif
	}
	
	void Line::setStartValue(const AudFloat &start)
	{
		_start = start;
		_range = _end - _start;
		_trigger = false;
	}
	
	void Line::setEndValue(const AudFloat &end)
	{
		_end = end;
		_range = _end - _start;
		_trigger = false;
	}
	
	void Line::setTime(const AudFloat &time)
	{
		Phasor::setFrequency (fabs(1.0 / time));
		_trigger = false;
	}
	
	void Line::Processing()
	{
		if (Phasor::_trigger)
			_output_1 = _end;
		else
		{
			Phasor::Processing();
			_output_1 = _start + (_output_1 * _range);
		}
	}
} //	end of namespace Aud
///EOF
