/***************************************************/
/*! \class Metronome
 \brief
 
 The AudioDrome Metronome class, implements 
 a trigger generator controlled in frequency.
 The resulting is "true", a sample for each 
 Period (1/freq), and "false" for all 
 remaining samples of the period.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Metronome.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	Metronome::Metronome(const bool &firstOut)
	{
#if __DEBUG__
		std::cout << "Metronome Constructor: " << this <<std::endl;
#endif
		if(firstOut)
			_accum = 1.0;
		else
			_accum = 0.0;
		_incrm = 0.0;
	}
	
	Metronome::~Metronome()
	{
#if __DEBUG__
		std::cout << "Metronome Destructor: " << this <<std::endl;
#endif
	}
	
	void Metronome::setFrequency(const AudFloat &freq) /*! Sampling Rate Change SLOT */
	{
		_freq = freq;
		_incrm = fabs(freq) / _localSR;
	}
	
	void Metronome::setSample(const unsigned long &sample)
	{
		_incrm = 1.0 / (AudFloat) (sample > 1.0 ? sample : 2.0);
	}
	
	void Metronome::setBpm(const AudFloat &bpm)
	{
		this->setFrequency(bpm / 60.0);
	}
	
	void Metronome::Processing()
	{
		_accum += _incrm;
		if (_accum < 1.0)
			_output_1 = 0.0f;
		else
		{
			_accum -= 1.0;
			_output_1 = 1.0f;
		}
	}
} //	end of namespace Aud
///EOF
