/***************************************************/
/*! \class OscilTimout
 \brief
 
 The AudioDrome OscilTimout class, inherits from Oscillator,
 implements an timer oscillator.
 When the execution time expires, 
 The oscillator goes off and the counter of instances is decremented
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "OscilTimout.h"

using namespace Aud; 
//  begin namespace
namespace Aud
{
	
	ul OscilTimout::_actives = 0;
	
	OscilTimout::OscilTimout(Buffer* wave, const INTERPOLATION& type, bool initialStatus) :
	Oscillator(wave, type), _dur(0), _countSamples(0), _status(initialStatus)
	{
#if __DEBUG__
		std::cout << "OscilTimout Constructor: " << this <<std::endl;
#endif
		this->setTime();
		
		if(_status)
			++_actives;
	}
	
	OscilTimout::~OscilTimout()
	{
#if __DEBUG__
		std::cout << "OscilTimout Destructor: " << this <<std::endl;
#endif
	}
	
	void OscilTimout::start()
	{
		if (!_status)
		{
			_status = true;
			_countSamples = 0;
			++_actives;
		}
#if __DEBUG__
		else
		{
			std::cout << "The current Oscillator is Active."<< std::endl;
		}
#endif
	}
	
	void OscilTimout::trigger()
	{
		_status = false;
		--_actives;
		this->start();
	}
	
	bool OscilTimout::getStatus() const
	{
		return _status;
	}
	
	int OscilTimout::getNumOscAtive()
	{
#if __DEBUG__
		std::cout << "Number of Oscillator actives is:  "<< _actives << std::endl;
#endif
		return _actives;
	}
	
	void OscilTimout::Processing()
	{
		if (_status)
		{
			if (_countSamples < _durSamples)
			{
				++_countSamples;
				Oscillator::Processing();
				return;
			}
			_status = false;
			--_actives;
		}
		_output_1 = 0.0;
		
	}
} //	end of namespace Aud
///EOF




