/***************************************************/
/*! \class Random
 \brief
 
 The AudioDrome Random class, implements a linear
 random number generator.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Random.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	Random::Random(const AudFloat &amplitude, 
				   const POLARITY &polar, 
				   const bool &seed)
	{
#if __DEBUG__
		std::cout << "Random Constructor: "<< this<<std::endl;
#endif
		this->setAmplitude(amplitude);
		this->setPolarity(BIPOLAR);
		this->setSeed(seed);
	}
	
	Random::~Random()
	{
#if __DEBUG__
		std::cout << "Random Destructor: "<< this<<std::endl;
#endif
	}
	
	void Random::setAmplitude(const AudFloat &amplitude)
	{
		_amplitude = amplitude;
	}
	
	void Random::setSeed(const bool &seed)
	{
		if (seed)
			srand(time(NULL));
		else
			srand (false);
	}
	
	void Random::setPolarity(const POLARITY &polar)
	{
		switch (polar)
		{
			case (UNIPOLAR):
				_polarFun = &Random::unipolar;
				break;
			case (BIPOLAR):
				_polarFun = &Random::bipolar;
				break;				
			default:
				_polarFun = &Random::bipolar;
		}
	}
	
	void Random::Processing()
	{
		_output_1 = (*_polarFun)(_amplitude);
	}
	
	AudFloat Random::unipolar(const AudFloat &amplitude)
	{
		/*Processing() function */
		return amplitude * (AudFloat(rand())/RAND_MAX);
	}
	
	AudFloat Random::bipolar(const AudFloat &amplitude)
	{
		/*Processing() function */
		return amplitude * 2.0 * ((AudFloat(rand())/RAND_MAX) - 0.5);
	}
	
	AudFloat Random::rangeRand(const AudFloat &min, const AudFloat &max)
	{
		/*Processing() function */
		return (AudFloat(rand())/RAND_MAX) * (max - min) + min;
	}
} //	end of namespace Aud
///EOF
