/***************************************************/
/*! \class Timer
 \brief
 
 The AudioDrome Timer class, keeps track of time.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Timer.h"
#include "AudioDrome.h"

using namespace Aud; 


//  begin namespace
namespace Aud
{
	
	void* threadPrint(void* user)
	{
		Timer* timerPtr = (Timer*) user;
		while (true)
		{
			timerPtr->printTime();
			usleep(timerPtr->_printWhenMs * 1000L);
		}
		return NULL;
	}
	
	Timer::Timer() : _isRunning(false)
	{
#if __DEBUG__
		std::cout << "Timer Constructor: "<< this<<std::endl;
#endif
		this->resetTimer();
		this->setPrintTimeSleep();
	}
	
	Timer::~Timer()
	{
#if __DEBUG__
		std::cout << "Timer Destructor: "<< this<<std::endl;
#endif
		if(_isRunning)
			this->printTimerStop();
	}
	
	void Timer::printTimerStart() throw(AudError)
	{
		if(!_isRunning)
		{
			_isRunning = true;
			int rc = pthread_create(&_thread, NULL, threadPrint, this);
			if(rc)
			{
				_isRunning = false;
				AudError er(NULL_POINTER);
				er.setMsgError("ERROR; return code from pthread_create(). No Timer Thread Created!");
				throw er;
			}
		}
	}
	
	void Timer::resetTimer()
	{
		_startTime = time(NULL);
		_day = 0;
		_hours = 0;
		_minuts = 0;
		_seconds = 0;
		_us = 0;
		_accumTime = 0.0;
	}
	
	void Timer::elapsedTime()
	{
		gettimeofday(&_tv, &_tz);
		
		_seconds = _tv.tv_sec - _startTime;
		
		if(_seconds >= 60)
		{
			_minuts++;
			_seconds = 0;
			_startTime = time(NULL);
		}
		if(_minuts >= 60)
		{
			_hours++;
			_minuts = 0;
		}
		if(_hours >= 24)
		{
			_day++;
			_hours = 0;
		}
		
		_us = _tv.tv_usec;
		
		_accumTime =  (_minuts * 60) + (_seconds + ((double) _us / 1000000.0));
	}
	
} //	end of namespace Aud
///EOF

