/***************************************************/
/*! \class Trigger
 \brief
 
 The AudioDrome Trigger class, informs 
 when a signal crosses a threshold.
 
 Questa classe implementa un generatore
 di trigger. Il trigger viene emesso quando
 il segnale in ingresso attraversa la soglia
 di valore indicata in threshold..
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "Trigger.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	Trigger::Trigger(const AudFloat &threshold, const TRIGGER &mode)
	{
#if __DEBUG__
		std::cout << "Trigger Constructor: "<< this<<std::endl;
#endif
		this->setThresHold(threshold);
		this->setMode(mode);
	}
	
	Trigger::~Trigger()
	{
#if __DEBUG__
		std::cout << "Trigger Destructor: "<< this<<std::endl;
#endif
	}
	
	void Trigger::setThresHold(const AudFloat &threshold)
	{
		_threshold = threshold;
	}
	
	void Trigger::setMode(const TRIGGER &mode)
	{
		switch (mode)
		{
			case UP:
				_modePtr = &Trigger::Up;
				break;
				
			case DOWN:
				_modePtr = &Trigger::Down;
				break;
				
			case BOTH:
				_modePtr = &Trigger::Both;
				break;
				
			default:
				_modePtr = &Trigger::Up;				
		}
	}
	
	void Trigger::Processing()
	{
		_output_1 = (this->*_modePtr)(_input_1);
	}
	
	AudFloat Trigger::Up(const AudFloat &input)
	{
		if (_old_sig <= _threshold && input > _threshold)
		{
			_old_sig = input;
			return 1.0;
		}
		else
		{
			_old_sig = input;
			return 0.0;
		}
	}
	
	AudFloat Trigger::Down(const AudFloat &input)
	{
		if (_old_sig >= _threshold && input < _threshold)
		{
			_old_sig = input;
			return 1.0;
		}
		else
		{
			_old_sig = input;
			return 0.0;
		}
	}
	
	AudFloat Trigger::Both(const AudFloat &input)
	{
		if ((_old_sig <= _threshold && input > _threshold) ||(_old_sig>= _threshold
															  && input < _threshold ))
		{
			_old_sig = input;
			return 1.0;
		}
		else
		{
			_old_sig = input;
			return 0.0;
		}
	}
} //	end of namespace Aud
///EOF
