/***************************************************/
/*! \class UpSampling
 \brief
 
 The AudioDrome UpSampling class, implements a 
 linear interpolation, converts a control 
 signal to an audio signal.
 Given an input value,  returns 
 setNumberSamples() samples interpolated.
 
 by Alessandro Petrolati 2006.
 www.alessandro-petrolati.it
 info@alessandro-petrolati.it
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/***************************************************/

#include "UpSampling.h"

using namespace Aud; 

//  begin namespace
namespace Aud
{
	UpSampling::UpSampling(const ul& nsamp) : _counter(0)
	{
#if __DEBUG__
		std::cout << "UpSampling Constructor: "<< this<<std::endl;
#endif
		this->setUpSampling(nsamp);
	}
	
	UpSampling::UpSampling(AudioDrome& obj) : _counter(0)
	{
#if __DEBUG__
		std::cout << "UpSampling Constructor: "<< this<<std::endl;
#endif
		this->setUpSampling(obj);
	}	
	
	UpSampling::~UpSampling()
	{
#if __DEBUG__
		std::cout << "UpSampling Destructor: "<< this<<std::endl;
#endif
	}
	
	void UpSampling::setUpSampling(const ul& nsamp)
	{
		if(nsamp > 1)
			_nsamp = nsamp;
		else
		{
#if __DEBUG__
			std::cout << "Number point > 1 default: 1 ( no interpolation)" << std::endl;
#endif
			_nsamp = 0;
		}
	}
	
	void UpSampling::Processing()
	{
		if (++_counter < _nsamp)
		{
			Interpolation::setInterpolationPoint( (AudFloat) _counter / (AudFloat) _nsamp );
			Interpolation::Processing();
		}
		else
		{
			_counter = 0;
			Interpolation::setInterpolationPoint(1.0);
			Interpolation::Processing();
			Interpolation::setValue1(_output_1);
			Interpolation::setValue2(_input_1);
		}
	}
} //	end of namespace Aud
///EOF
